@@ -13,6 +13,11 @@ class Purchase(metaclass=PoolMeta):
             'purchase.purchase-ignored-account.invoice.line',
             'purchase', 'invoice', 'Invoice Lines Ignored', readonly=True)
 
+    @property
+    def invoice_line_standalone(self):
+        party = self.invoice_party or self.party
+        return party.purchase_invoice_line_standalone
+
     def get_invoice_lines(self, name):
         return list({il.id for l in self.lines for il in l.invoice_lines})
 
@@ -20,41 +25,36 @@ class Purchase(metaclass=PoolMeta):
     def search_invoice_lines(cls, name, clause):
         return [('lines.' + clause[0],) + tuple(clause[1:])]
 
-    def create_invoice(self):
+    @classmethod
+    def _save_invoice(cls, invoices):
         pool = Pool()
-        Invoice = pool.get('account.invoice')
         InvoiceLine = pool.get('account.invoice.line')
 
-        invoice = super(Purchase, self).create_invoice()
+        lines = []
+        non_standalone = {}
+        for purchase, invoice in invoices.items():
+            if purchase.invoice_line_standalone:
+                for line in invoice.lines:
+                    if line.type == 'line':
+                        line.invoice = None
+                        line.party = invoice.party
+                        lines.append(line)
+            else:
+                non_standalone[purchase] = invoice
+        InvoiceLine.save(lines)
 
-        if invoice:
-            lines_to_delete = [l for l in invoice.lines if l.type != 'line']
-            lines = [l for l in invoice.lines if l.type == 'line']
-            InvoiceLine.write(lines, {
-                'invoice': None,
-                'invoice_type': invoice.type,
-                'party': invoice.party.id,
-                })
-            InvoiceLine.delete(lines_to_delete)
-            Invoice.cancel([invoice])
-            Invoice.delete([invoice])
-            return None
-        return invoice
+        super()._save_invoice(non_standalone)
 
     def get_invoice_state(self):
         state = super(Purchase, self).get_invoice_state()
-        skips = set(x.id for x in self.invoice_lines_ignored)
-        invoice_lines = [l for l in self.invoice_lines if l.id not in skips]
-        if invoice_lines:
-            if any(l.invoice and l.invoice.state == 'cancelled'
-                    for l in invoice_lines):
-                return 'exception'
-            elif (state == 'paid'
-                    and all(l.invoice for l in invoice_lines)
-                    and all(l.invoice.state == 'paid' for l in invoice_lines)):
-                return 'paid'
-            else:
-                return 'waiting'
+        skips = set(self.invoice_lines_ignored)
+        standalone_lines = [
+            l for l in self.invoice_lines if l not in skips and not l.invoice]
+        if standalone_lines:
+            state = {
+                'paid': 'partially paid',
+                'none': 'pending',
+                }.get(state, state)
         return state
 
     @classmethod
@@ -71,10 +71,11 @@ class PurchaseIgnoredInvoiceLine(ModelSQL):
     'Purchase - Ignored Invoice Line'
     __name__ = 'purchase.purchase-ignored-account.invoice.line'
     _table = 'purchase_invoice_line_ignored_rel'
-    purchase = fields.Many2One('purchase.purchase', 'Purchase',
-            ondelete='CASCADE', select=True, required=True)
-    invoice = fields.Many2One('account.invoice.line', 'Invoice Line',
-            ondelete='RESTRICT', select=True, required=True)
+    purchase = fields.Many2One(
+        'purchase.purchase', "Purchase", ondelete='CASCADE', required=True)
+    invoice = fields.Many2One(
+        'account.invoice.line', "Invoice Line",
+        ondelete='RESTRICT', required=True)
 
 
 class HandleInvoiceException(metaclass=PoolMeta):
